==> ibiz-model-8.1.0.317-sources.jar: net/ibizsys/model/control/toolbar/PSDETBGroupItemImpl.java <==
package net.ibizsys.model.control.toolbar;



public class PSDETBGroupItemImpl extends net.ibizsys.model.control.toolbar.PSDEToolbarItemImpl implements net.ibizsys.model.control.toolbar.IPSDETBGroupItem
		,net.ibizsys.model.control.toolbar.IPSDECMGroupItem{

	public final static String ATTR_GETPSDECONTEXTMENUITEMS = "getPSDEContextMenuItems";
	public final static String ATTR_GETPSDETOOLBARITEMS = "getPSDEToolbarItems";
	public final static String ATTR_ISVALID = "valid";

	private java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> psdecontextmenuitems = null;
	public java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> getPSDEContextMenuItems(){
		if(this.psdecontextmenuitems == null){
			com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDECONTEXTMENUITEMS);
			if(value == null){return null;}
			com.fasterxml.jackson.databind.node.ArrayNode arrayNode = (com.fasterxml.jackson.databind.node.ArrayNode)value;
			if(arrayNode.size() == 0){return null;}
			java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> list = new java.util.ArrayList<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem>();
			for(int i = 0;i<arrayNode.size();i++) {
				net.ibizsys.model.control.toolbar.IPSDEContextMenuItem obj = this.getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEContextMenuItem.class, (com.fasterxml.jackson.databind.node.ObjectNode)arrayNode.get(i),ATTR_GETPSDECONTEXTMENUITEMS);
				if(obj!=null)list.add(obj);
			}
			this.psdecontextmenuitems = list;
		}
		return (this.psdecontextmenuitems.size() == 0)? null : this.psdecontextmenuitems;
	}

	public net.ibizsys.model.control.toolbar.IPSDEContextMenuItem getPSDEContextMenuItem(Object objKey, boolean bTryMode){
		return getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEContextMenuItem.class, this.getPSDEContextMenuItems(), objKey, bTryMode);
	}
	public void setPSDEContextMenuItems(java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> list){
		this.psdecontextmenuitems = list;
	}

	private java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> psdetoolbaritems = null;
	public java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> getPSDEToolbarItems(){
		if(this.psdetoolbaritems == null){
			com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDETOOLBARITEMS);
			if(value == null){return null;}
			com.fasterxml.jackson.databind.node.ArrayNode arrayNode = (com.fasterxml.jackson.databind.node.ArrayNode)value;
			if(arrayNode.size() == 0){return null;}
			java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> list = new java.util.ArrayList<net.ibizsys.model.control.toolbar.IPSDEToolbarItem>();
			for(int i = 0;i<arrayNode.size();i++) {
				net.ibizsys.model.control.toolbar.IPSDEToolbarItem obj = this.getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEToolbarItem.class, (com.fasterxml.jackson.databind.node.ObjectNode)arrayNode.get(i),ATTR_GETPSDETOOLBARITEMS);
				if(obj!=null)list.add(obj);
			}
			this.psdetoolbaritems = list;
		}
		return (this.psdetoolbaritems.size() == 0)? null : this.psdetoolbaritems;
	}

	public net.ibizsys.model.control.toolbar.IPSDEToolbarItem getPSDEToolbarItem(Object objKey, boolean bTryMode){
		return getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEToolbarItem.class, this.getPSDEToolbarItems(), objKey, bTryMode);
	}
	public void setPSDEToolbarItems(java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> list){
		this.psdetoolbaritems = list;
	}

	public boolean isValid(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISVALID);
		if(value == null){
			return true;
		}
		return value.asBoolean();
	}
}

==> ibiz-model-8.1.0.516-sources.jar: net/ibizsys/model/control/toolbar/PSDETBGroupItemImpl.java <==
package net.ibizsys.model.control.toolbar;



public class PSDETBGroupItemImpl extends net.ibizsys.model.control.toolbar.PSDEToolbarItemImpl implements net.ibizsys.model.control.toolbar.IPSDETBGroupItem
		,net.ibizsys.model.control.toolbar.IPSDECMGroupItem{

	public final static String ATTR_GETACTIONLEVEL = "actionLevel";
	public final static String ATTR_GETBORDERSTYLE = "borderStyle";
	public final static String ATTR_GETBUTTONSTYLE = "buttonStyle";
	public final static String ATTR_GETPSDECONTEXTMENUITEMS = "getPSDEContextMenuItems";
	public final static String ATTR_GETPSDETOOLBARITEMS = "getPSDEToolbarItems";
	public final static String ATTR_ISVALID = "valid";

	public int getActionLevel(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETACTIONLEVEL);
		if(value == null){
			return 100;
		}
		return value.asInt();
	}

	public java.lang.String getBorderStyle(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETBORDERSTYLE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getButtonStyle(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETBUTTONSTYLE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	private java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> psdecontextmenuitems = null;
	public java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> getPSDEContextMenuItems(){
		if(this.psdecontextmenuitems == null){
			com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDECONTEXTMENUITEMS);
			if(value == null){return null;}
			com.fasterxml.jackson.databind.node.ArrayNode arrayNode = (com.fasterxml.jackson.databind.node.ArrayNode)value;
			if(arrayNode.size() == 0){return null;}
			java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> list = new java.util.ArrayList<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem>();
			for(int i = 0;i<arrayNode.size();i++) {
				net.ibizsys.model.control.toolbar.IPSDEContextMenuItem obj = this.getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEContextMenuItem.class, (com.fasterxml.jackson.databind.node.ObjectNode)arrayNode.get(i),ATTR_GETPSDECONTEXTMENUITEMS);
				if(obj!=null)list.add(obj);
			}
			this.psdecontextmenuitems = list;
		}
		return (this.psdecontextmenuitems.size() == 0)? null : this.psdecontextmenuitems;
	}

	public net.ibizsys.model.control.toolbar.IPSDEContextMenuItem getPSDEContextMenuItem(Object objKey, boolean bTryMode){
		return getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEContextMenuItem.class, this.getPSDEContextMenuItems(), objKey, bTryMode);
	}
	public void setPSDEContextMenuItems(java.util.List<net.ibizsys.model.control.toolbar.IPSDEContextMenuItem> list){
		this.psdecontextmenuitems = list;
	}

	private java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> psdetoolbaritems = null;
	public java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> getPSDEToolbarItems(){
		if(this.psdetoolbaritems == null){
			com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDETOOLBARITEMS);
			if(value == null){return null;}
			com.fasterxml.jackson.databind.node.ArrayNode arrayNode = (com.fasterxml.jackson.databind.node.ArrayNode)value;
			if(arrayNode.size() == 0){return null;}
			java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> list = new java.util.ArrayList<net.ibizsys.model.control.toolbar.IPSDEToolbarItem>();
			for(int i = 0;i<arrayNode.size();i++) {
				net.ibizsys.model.control.toolbar.IPSDEToolbarItem obj = this.getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEToolbarItem.class, (com.fasterxml.jackson.databind.node.ObjectNode)arrayNode.get(i),ATTR_GETPSDETOOLBARITEMS);
				if(obj!=null)list.add(obj);
			}
			this.psdetoolbaritems = list;
		}
		return (this.psdetoolbaritems.size() == 0)? null : this.psdetoolbaritems;
	}

	public net.ibizsys.model.control.toolbar.IPSDEToolbarItem getPSDEToolbarItem(Object objKey, boolean bTryMode){
		return getPSModelObject(net.ibizsys.model.control.toolbar.IPSDEToolbarItem.class, this.getPSDEToolbarItems(), objKey, bTryMode);
	}
	public void setPSDEToolbarItems(java.util.List<net.ibizsys.model.control.toolbar.IPSDEToolbarItem> list){
		this.psdetoolbaritems = list;
	}

	public boolean isValid(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISVALID);
		if(value == null){
			return true;
		}
		return value.asBoolean();
	}
}
